darkhistory.physics.xe_Saha — DarkHistory documentation

# darkhistory.physics.xe_Saha

`darkhistory.physics.` `xe_Saha`(rs, species)

  Saha equilibrium ionization value for H and He.

  Parameters: | rs : float The redshift in 1+z. species : {‘HI’, ‘HeI’} The relevant species.
  Returns: | float The Saha equilibrium xe.

  Notes

  See astro-ph/9909275 and 1011.3758 for details.

#### Previous topic

darkhistory.physics.C_He

#### Next topic

darkhistory.physics.d_xe_Saha_dz

### This Page

Show Source